#Query the RPM database to find which release we are running.
################################################################

#Try to keep all platform-specific definitions up here instead of putting
#them in the body of the spec file.

%if %(rpmquery fedora-release | grep -cv 'not installed$')
    #Fedora Core - http://fedora.redhat.com
    %define VER %(rpmquery --qf '%{VERSION}' fedora-release)
    %define DISTTAG fc
    %if %{VER} >= 3
      %define RBROWSER firefox
    %endif
    %if %{VER} >= 4
      %define GCC4 1
      %define RPDFVIEWER evince
    %endif
    %if %{VER} >= 5
      %define XORG 1
    %endif
%endif

%if %(rpmquery redhat-release | grep -v 'not installed$' | grep -c -e '-[0-9][AEW]S')
    #Red Hat Enterprise Linux - http://www.redhat.com
    %define VER %(rpmquery --qf '%{VERSION}' redhat-release)	
    %define DISTTAG rh
%endif

%if %(rpmquery centos-release | grep -v 'not installed$' | grep -c -e '-[0-9]-[0-9].[0-9]')
    #CENTOS Linux - http://www.centos.org/ and ROCKS-Linux Cluster Installation
    %define VER %(rpmquery --qf '%{VERSION}' centos-release)	
    %define DISTTAG centos.
%endif

%if %(rpmquery sl-release | grep -cv 'not installed$')
    #Scientific Linux. A RHEL work-alike -  http://www.scientificlinux.org
    # note nasty use of \\. here grr!
    %define VER %(rpmquery --qf '%{VERSION}' sl-release | sed 's/\\.//g')
    %define DISTTAG sl
%endif

## I'm going to just cheat here and hardcode these
      %define DISTTAG sl
      %define VER 5x
      %define XORG 1
      %define RBROWSER firefox
      %define GCC4 1
      %define RPDFVIEWER evince

################################################################

%if 0%{?GCC4}
   %define FORTRAN gfortran
%else
   %define FORTRAN g77
%endif

%if 0%{?XORG}
   %define X11DEV xorg-x11-proto-devel, libXt-devel
%else
   %define X11DEV XFree86-devel
%endif

################################################################
#Query the RPM database to determine if an up-to-date version of 
#texinfo/makeinfo is available

%if %( x=$(rpmquery --qf '%{VERSION}' texinfo); if ((! $?)); then echo "$x" | { IFS=.; read maj min rest; echo $((maj*100+min>=407)); } ; else echo 0; fi )
	# assume makeinfo is up to date (cf. configure), since texinfo is up to date
	%define INFO 1
%endif

################################################################

%define REL 1
Summary: A language for data analysis and graphics
Name: R
Version: 2.4.1
Epoch: 2
Release: %{REL}.%{DISTTAG}%{VER}
Source0: ftp://cran.r-project.org/pub/R/src/base/R-2/R-%{version}.tar.gz
License: GPL
Group: Applications/Engineering
#Packager: Martyn Plummer <martyn.plummer@r-project.org>
URL: http://www.r-project.org
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Icon: logosm-trans.gif
BuildRequires: gcc-c++, gcc-%{FORTRAN}
BuildRequires: libpng-devel, libjpeg-devel, readline-devel, libtermcap-devel
BuildRequires: tetex-latex, texinfo, tcl-devel, tk-devel
# X11 moved from XFree86 to Xorg in Fedora Core 2 BUT xorg-x11-devel
# "provides" XFree86-devel, so it still works as a build requirement.
BuildRequires: %{X11DEV}

%description
`GNU S' - A language and environment for statistical computing and
graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

R is designed as a true computer language with control-flow
constructions for iteration and alternation, and it allows users to
add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be linked
and called at run time.

%package devel
Summary: files for development of R packages.
Group: Applications/Engineering
Requires: R = %{epoch}:%{version}-%{release}
# You need all the BuildRequires for the development version
Requires: gcc-c++, gcc-%{FORTRAN}
Requires: libpng-devel, libjpeg-devel, readline-devel, libtermcap-devel
Requires: XFree86-devel
Requires: tetex-latex, texinfo, tcl-devel, tk-devel
%description devel
Install R-devel if you are going to develop or compile R packages. 

This is just a stub package containing the documentation on "Writing R
Extensions".  However, installing it will ensure that the build
environment for R packages is correct.

%package -n libRmath
Summary: standalone math library from the R project
Group: Development/Libraries
%description -n libRmath
A standalone library of mathematical and statistical functions derived
from the R project.  This packages provides the shared libRmath library.

%package -n libRmath-devel
Summary: standalone math library from the R project
Group: Development/Libraries
Requires: libRmath = %{epoch}:%{version}
%description -n libRmath-devel
A standalone library of mathematical and statistical functions derived
from the R project.  This packages provides the static libRmath library
and header files.

%prep
%setup -q 

%build
export R_PRINTCMD="lpr"
export R_BROWSER="%{_bindir}/mozilla" 
%{?RBROWSER: R_BROWSER=%{_bindir}/%{RBROWSER}}
export R_PDFVIEWER="%{_bindir}/ggv"
%{?RPDFVIEWER: R_PDFVIEWER=%{_bindir}/%{RPDFVIEWER}}
export F77=%{FORTRAN}
( %configure \
    --without-blas \
    --with-tcl-config=%{_libdir}/tclConfig.sh \
    --with-tk-config=%{_libdir}/tkConfig.sh \
    --enable-R-shlib )\
 | egrep '^R is now|^ |^$' - > CAPABILITIES
make 
(cd src/nmath/standalone; make)
make check-all
make pdf
#We can only "make info" if we have an up to date version of texinfo
%{?INFO: make info}

%install

%makeinstall rhome=${RPM_BUILD_ROOT}%{_libdir}/R \
             install-pdf %{?INFO:install-info} 
rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir.old

#Install libRmath files
(cd src/nmath/standalone; make install \
    includedir=${RPM_BUILD_ROOT}%{_includedir} \
    libdir=${RPM_BUILD_ROOT}%{_libdir})

#Fix location of R_HOME_DIR in shell wrapper.
sed -e "s@R_HOME_DIR=.*@R_HOME_DIR=%{_libdir}/R@" bin/R \
  > ${RPM_BUILD_ROOT}%{_libdir}/R/bin/R
chmod 755 ${RPM_BUILD_ROOT}%{_libdir}/R/bin/R 
sed -e "s@R_HOME_DIR=.*@R_HOME_DIR=%{_libdir}/R@" bin/R \
  > ${RPM_BUILD_ROOT}%{_bindir}/R
chmod 755 ${RPM_BUILD_ROOT}%{_bindir}/R

mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
echo "%{_libdir}/R/lib" > $RPM_BUILD_ROOT/etc/ld.so.conf.d/%{name}-%{_arch}.conf
%files
%defattr(-, root, root)
%{_bindir}/R
%{_libdir}/R
%{?INFO:%{_infodir}/R-*.info*}
%{_mandir}/man1/*
/etc/ld.so.conf.d/*
%doc %{_libdir}/R/doc
%doc CAPABILITIES

%files devel
%defattr(-, root, root)
%doc doc/manual/R-exts.html

%files -n libRmath
%defattr(-, root, root)
%{_libdir}/libRmath.so

%files -n libRmath-devel
%defattr(-, root, root)
%{_libdir}/libRmath.a
%{_includedir}/Rmath.h

%clean
rm -rf ${RPM_BUILD_ROOT}

%post 
%if 0%{?INFO}
   # Create directory entries for info files
   # (optional doc files, so we must check that they are installed)
   for doc in admin data exts FAQ intro lang; do
      file=%{_infodir}/R-${doc}.info.gz
      if [ -e $file ]; then
         /sbin/install-info ${file} %{_infodir}/dir 2>/dev/null
      fi
   done
%endif
/sbin/ldconfig

%preun 
if [ $1 = 0 ]; then
   %if 0%{?INFO}
      # Delete directory entries for info files (if they were installed)
      for doc in admin data exts FAQ intro lang; do
         file=%{_infodir}/R-${doc}.info.gz
         if [ -e ${file} ]; then
            /sbin/install-info --delete R-${doc} %{_infodir}/dir 2>/dev/null
         fi
      done
   %endif
fi

%postun 
/sbin/ldconfig

%post -n libRmath
/sbin/ldconfig

%postun -n libRmath
/sbin/ldconfig

%changelog
* Wed Apr 11 2007 Troy Dawson <dawson@fnal.gov> 2:2.4.1-1
- updated to version 2.4.1

* Tue Mar 21 2006 Martyn Plummer <plummer@iarc.fr> 1:2.2.1-2
- Modified for FC5

* Tue Jan 3 2006 Martyn Plumer <plummber@iarc.fr> 1:2.2.1-1
- Restored CAPABILITIES file lost in 2.2.1beta

* Mon Dec 12 2005 Martyn Plummer <plummer@iarc.fr> 1:2.2.1beta-1
- Configure uses --without-blas by default.
- Install pdf manuals.
- All toplevel documentation files are installed into _libdir/R
  as they may be required by R (qv note on AUTHORS and THANKS below).
- Legacy scripts for rebuilding package indices removed.

* Mon Sep 19 2005 Martyn Plummer <plummer@iarc.fr> 1:2.2.0-0
- R now compiles with gcc 4.0.1 and default rpm optimization flags.

* Wed Jul 13 2005 Martyn Plummer <plummer@iarc.fr> 1:2.1.1-2
- The files AUTHORS and THANKS need to be installed into _libdir/R
  as they are required by the function contributors().  Previously
  they were installed only as documentation files.

* Tue Jun 21 2005 Martyn Plummer <plummer@iarc.fr>
- Corrected date error in SPEC file.

* Sun Jun 19 2005 Martyn Plummer <plummer@iarc.fr>
- Dropped support for Red Hat boxed set.
- Synchronized with Fedora Extras 4 RPM by Tom Calloway
  including support for shared R library.
- Added gfortran support. However, gcc 4.0.0 will not compile R correctly
  with the default optimization flags, so there is a temporary work-around.

* Wed Jun 15 2005 Gernot Stocker <gernot.stocker@tugraz.at>
- Adaptations for CentOS and Rocks-Linux, tested under Release 4.0

* Sat Apr 30 2005 Joseph P. Skudlarek <Jskud@Jskud.com> 0:2.1.0-0.fdr.3
- Install R-data.info file as well.
- Make info processing conditional on texinfo version, not platform release,
  so that if a new enough version is installed, we will build and install info.

* Mon Apr 18 2005 Martyn Plummer <plummer@iarc.fr> 0:2.1.0-0.fdr.1
- Built R 2.1.0.  R now supports internationalization, so the patch
  to set the locale to "C" is now dropped.
- install.packages() exits gracefully with a helpful message if
  the file INSTALL is not present, so this is now included in the
  R-devel package.

* Mon Mar 14 2005 Martyn Plummer <plummer@iarc.fr> 0:2.0.1-0.fdr.5
- Added support for Scientific Linux (http://www.scientificlinux.org)
  A distribution based on RHEL. Thanks to Jon Peatfield.

* Mon Feb 28 2005 Martyn Plummer <plummer@iarc.fr> 0:2.0.1-0.fdr.4
- Fixed file ownership in R-devel and libRmath packages

* Wed Feb 16 2005 Martyn Plummer <plummer@iarc.fr> 0:2.0.1-0.fdr.3
- R-devel package is now a stub package with no files, except a documentation
  file (RPM won't accept sub-packages with no files). R now conflicts
  with earlier (i.e 0:2.0.1-0.fdr.2) versions of R-devel.
- Created libRmath subpackage with shared library.

* Mon Jan 31 2005 Martyn Plummer <plummer@iarc.fr> 0:2.0.1-0.fdr.2
- Created R-devel and libRmath-devel subpackages

* Mon Nov 15 2004 Martyn Plummer <plummer@iarc.fr> 0:2.0.1-0.fdr.1
- Built R 2.0.1

* Wed Nov 10 2004 Martyn Plummer <plummer@iarc.fr> 0:2.0.0-0.fdr.3
- Set R_PRINTCMD at configure times so that by default getOption(printcmd)
  gives "lpr".
- Define macro fcx for all Fedora distributions. This replaces Rinfo

* Tue Oct 12 2004 Martyn Plummer <plummer@iarc.fr> 0:2.0.0-0.fdr.2
- Info support is now conditional on the macro Rinfo, which is only
  defined for Fedora 1 and 2. 

* Thu Oct 7 2004 Martyn Plummer <plummer@iarc.fr> 0:2.0.0-0.fdr.1
- Built R 2.0.0
- There is no longer a BUGS file, so this is not installed as a 
  documentation file.
